// List of days
var date;
var tage;
var startWith;
var monate;

// The marked day
var selectedDay;
var selectedDayCol;

var fontEnd;


function setLanguage(lang) {

	tage = localizedStrings["tage_"+lang+"_"+startWith];
	monate = localizedStrings["monate_" +lang];
	
	buildDayLabels();	
	showMonthAndYear();	
}


// Displays the selected month and year
function showMonthAndYear() {
	document.getElementById('monat').innerHTML = monate[date.getMonth()];
	document.getElementById('jahr').innerText = date.getFullYear();
}


// Button-Function to reselect the actual date
function actualDate() {
	var temp = new Date();
	date = new Date(temp.getFullYear(), temp.getMonth(), 1);
	buildDays();
	showMonthAndYear()

	setKalenderwoche();
}


// Highlight the actual or selected day
function highlightDay(actual) {
	if (selectedDay != null)
		selectedDay.style.color = selectedDayCol;
	selectedDayCol = actual.style.color;
	selectedDay = actual;
	selectedDay.style.color = "#6666FF";
	
	setKalenderwoche();
}


// Checks if the day of a month and year is valid
function dateCheck(day) {
	var temp = new Date(date.getFullYear(), date.getMonth(), day);
	if (temp.getFullYear() == date.getFullYear() && temp.getMonth() == date.getMonth())
		return true;
	else
		return false;
}


// Build the calendar with all days of a month
function buildDays() {
	var monthDiv = document.getElementById("tage");
	
	// First delete the old values
	if (monthDiv.hasChildNodes()) {
		var children = monthDiv.childNodes;
		var count = children.length;
		for(var j=0; j < count; j++) {
			monthDiv.removeChild(children[0]);
		}
	}
	
	// Dummy days to start at the correct week-day
	var day = date.getDay();
	var sundayKorr = -1;
		
	if (day == 0 && startWith == "monday") {
		day = 7;
	}
	
	if (day != 0) {
		if (startWith == "monday") {
			day -= 1;
			sundayKorr = 0;
		}
		
		for (var i=0; i<day; i++) {
			var dateSpan = document.createElement("span");
		
			monthDiv.appendChild(dateSpan);
			sundayKorr++;
		}
	}

	// Insert all days of the month
	for (var i=1; i<=31; i++) {
		if (i>27 && dateCheck(i) != true)
			break;
			
		var dateSpan = document.createElement("span");
		
		dateSpan.innerText = i;
		dateSpan.setAttribute("id", "tage"+i);
		dateSpan.setAttribute("onmousedown", "highlightDay(this);");
		if (((i+sundayKorr+1) % 7) == 0)
			dateSpan.style.setProperty("color", "#FFCC99");
		else if (((i+sundayKorr) % 7) == 0)
			dateSpan.style.setProperty("color", "#FFCC99");
		
		monthDiv.appendChild(dateSpan);
	}

	// Select the actual day if the user selected the actual month and year
	var temp = new Date();
	if (temp.getFullYear() == date.getFullYear() && temp.getMonth() == date.getMonth()) {
		selectedDay = document.getElementById("tage"+temp.getDate());
		selectedDayCol = selectedDay.style.color;
		selectedDay.style.color = "#6666FF";
	}
	else {
		selectedDay = null;
		selectedDayCol = null;
	}	
}


// Creates a new date after user pushed next or forward button
function createNewDate(todo) {
	var month = date.getMonth();
	var year = date.getFullYear();

	if (todo == 1) {
		month++;
		if (month > 11) {
			year++;
			month = 0;
		}
	} else {
		month--;
		if (month < 0) {
			year--;
			month = 11;
		}
	}
	
	date = new Date(year, month, 1);
}


// Button action for the previous month
function previousMonth() {
	createNewDate(0);
	buildDays();
	showMonthAndYear();
}	


// Button action for the next month
function nextMonth() {
	createNewDate(1);
	buildDays();
	showMonthAndYear();
}	


// Initialization
function start()
{
	fontEnd = widget.preferenceForKey("font");
    if (fontEnd == null || fontEnd.length == 0) {
        fontEnd = "tng";
        widget.setPreferenceForKey(fontEnd,"font");
    }

    document.getElementById('dayFontList').value = fontEnd;


	document.getElementById('monat').className = "monat_"+fontEnd;
	document.getElementById('jahr').className = "jahr_"+fontEnd;
	document.getElementById('mainBody').className = "bodyFont_"+fontEnd;

	document.getElementById('tage').className = "tage_"+fontEnd;

	document.getElementById('flip').style.visibility = "hidden";

	var temp = new Date();
	date = new Date(temp.getFullYear(), temp.getMonth(), 1);

	var lang = widget.preferenceForKey("language");
    if (lang == null || lang.length == 0) {
        lang = "DE";
       	widget.setPreferenceForKey(lang, "language");
    }

    document.getElementById('languageList').value = lang;


	startWith = widget.preferenceForKey("startWith");
    if (startWith == null || startWith.length == 0) {
        startWith = "monday";
        widget.setPreferenceForKey(startWith,"startWith");
    }

    document.getElementById('startDayList').value = startWith;

	tage = localizedStrings["tage_"+lang+"_"+startWith];
	monate = localizedStrings["monate_" +lang];
 	
	buildDayLabels();	
	buildDays();
	showMonthAndYear();
	
	setKalenderwoche();
}


function buildDayLabels() {
	// The day labels
	for (var i=0; i<7; i++) {
		document.getElementById("tag"+i).innerText = tage[i];		
	}
}


function setKalenderwoche() {

	var kw = calculateKalenderwoche(new Date(date.getFullYear(), 0, 1), new Date(date.getFullYear(), date.getMonth(), selectedDay.innerText));

	//Falls in der ersten Jahreswoche die KW von vorherigen Jahr bernommen wird
	if (kw == 0)
		kw = calculateKalenderwoche(new Date(date.getFullYear()-1, 0, 1), new Date(date.getFullYear()-1, 11, 31));
		
	var lastDayOfYear = new Date(date.getFullYear(), 11, 31);
	if (lastDayOfYear.getDay() < 5 && date.getMonth() == 11 && selectedDay.innerText >= 28) {
		var temp = new Date(date.getFullYear(), 11, selectedDay.innerText);
		if (temp.getDay() < 5 && temp.getDay() > 0)
			kw = 1;
	}
		
	document.getElementById("kalenderwochen").innerText = "W" + (kw < 10 ? "0" : "") +kw;
}

function calculateKalenderwoche(firstdate, lastdate) {

	var firstDayOfMonth = lastdate;
	var firstDayOfYear = firstdate;

	var day = firstDayOfYear.getDay();
	
	if (day == 0) {
		day = 7;
	}
				
	var korr = 0;
	var kw = 0;
		
	if (day < 5)
		korr = 1;
	
	var time1 = firstDayOfMonth.getTime();
	var time2 = firstDayOfYear.getTime();
	
	kw = ((time1 - time2) / 86400000) +day -1;
	// Rundungfehler beheben um stellenweise falsche Berechnungen zu verhindern
	kw = Math.ceil(kw);	
	
	kw = (Math.floor(kw/7) +korr);

  return kw;
}


function showbackside(event)
{
	var front = document.getElementById("body");
	var back = document.getElementById("behind");
	var cal = document.getElementById("calendar");
	var labels = document.getElementById("labels");
	var monat = document.getElementById("monat");
	var jahr = document.getElementById("jahr");
	var tage = document.getElementById("tage");
	var lang = document.getElementById("kalenderwochen");
	var i = document.getElementById("flip");
	var ib = document.getElementById("fliprollie");
	var arr_up = document.getElementById("arrow_up");
	var actual_date = document.getElementById("actual_date");
	var arr_down = document.getElementById("arrow_down");
	
	
	cal.style.visibility = "hidden";
	labels.style.visibility = "hidden";
	monat.style.visibility = "hidden";
	jahr.style.visibility = "hidden";
	lang.style.visibility = "hidden";
	tage.style.visibility = "hidden";
	i.style.visibility = "hidden";
	ib.style.visibility = "hidden";
	arr_up.style.visibility = "hidden";
	actual_date.style.visibility = "hidden";
	arr_down.style.visibility = "hidden";
	
	for (var i=0; i<7; i++)
		document.getElementById("tag"+i).visibility = "hidden";
	
	
	
	if (window.widget)
		widget.prepareForTransition("ToBack");
	
	front.style.display="none";
	back.style.display="block";
	document.getElementById('fliprollie').style.display = 'none';
	
	if (window.widget)		
		setTimeout ('widget.performTransition();', 0);	

}
	
function doneMouseUp(event)
{
	var front = document.getElementById("body");
	var back = document.getElementById("behind");
	var cal = document.getElementById("calendar");
	var labels = document.getElementById("labels");
	var monat = document.getElementById("monat");
	var jahr = document.getElementById("jahr");
	var tage = document.getElementById("tage");
	var lang = document.getElementById("kalenderwochen");
	var i = document.getElementById("flip");
	var ib = document.getElementById("fliprollie");
	var arr_up = document.getElementById("arrow_up");
	var actual_date = document.getElementById("actual_date");
	var arr_down = document.getElementById("arrow_down");
	
	
	cal.style.visibility = "visible";
	labels.style.visibility = "visible";
	monat.style.visibility = "visible";
	jahr.style.visibility = "visible";
	lang.style.visibility = "visible";
	tage.style.visibility = "visible";
	i.style.visibility = "visible";
	ib.style.visibility = "visible";
	arr_up.style.visibility = "visible";
	actual_date.style.visibility = "visible";
	arr_down.style.visibility = "visible";
	
	for (var i=0; i<7; i++)
		document.getElementById("tag"+i).visibility = "hidden";

	
	
	if (window.widget)
		widget.prepareForTransition("ToFront");
	
	front.style.display="block";
	back.style.display="none";
	if (window.widget)
		setTimeout ('widget.performTransition();', 0);

	
}	
	
function languageChanged(list) {	
	var listIndex = list.selectedIndex;
	
	setLanguage(list[listIndex].value);

	widget.setPreferenceForKey(list[listIndex].value,"language");
}	

function startDayChanged(list) {	
	var listIndex = list.selectedIndex;
	
	startWith = list[listIndex].value;
	setLanguage(document.getElementById("languageList").value);
	buildDays();

	widget.setPreferenceForKey(startWith,"startWith");
}	

function fontChanged(list) {
	var listIndex = list.selectedIndex;

	fontEnd = list[listIndex].value;
	
	document.getElementById('mainBody').className = "bodyFont_" +fontEnd;
	document.getElementById('monat').className = "monat_" +fontEnd;
	document.getElementById('jahr').className = "jahr_" +fontEnd;

	document.getElementById('tage').className = "tage_" +fontEnd;
	
	buildDays();
	
	widget.setPreferenceForKey(fontEnd,"font");
}
	
if (window.widget)
{
	widget.onshow = onshow;
}

function showFront(event) {
	if (window.widget) {
		window.widget.prepareForTransition("ToFront");
	}
	if (window.widget) {
		setTimeout("window.widget.performTransition()", 0);
	}
}

var updatedOn = new Date();

function onshow () {

	if (mustUpdate() == 1) {
   		actualDate();
   		updatedOn = new Date();
   	}
}


function mustUpdate() {
	
	var temp = new Date();
	
	if (temp.getFullYear() == updatedOn.getFullYear() && 
		temp.getMonth() == updatedOn.getMonth() &&
		temp.getDate() == updatedOn.getDate())
		return 0;
	else
		return 1;
}


var flipShown = false;

function mouseover (event)
{
	if (document.getElementById("body").style.display != "none") {
		if (!flipShown)
		{
			document.getElementById('flip').style.visibility = "visible";
			flipShown = true;
		}
	}	
}

function mouseexit (event)
{
	if (flipShown)
	{
		document.getElementById('flip').style.visibility = "hidden";
		flipShown = false;
	}
}


function enterflip(event)
{
	document.getElementById('fliprollie').style.display = 'block';
	document.getElementById('flip').style.display = 'block';
}

function exitflip(event)
{
	document.getElementById('fliprollie').style.display = 'none';
}